@@ -3,24 +3,27 @@ from python_helper.api.src.domain import Constant as c
 from python_helper.api.src.service import ObjectHelper, StringHelper, ReflectionHelper
 
 def getColorValue(thing, color) :
-    return color if ObjectHelper.isNotNone(color) else c.NATIVE_PROMPT_COLOR.get(ReflectionHelper.getName(type(thing)), c.DEFAULT_COLOR)
+    return color if ObjectHelper.isNotNone(color) else c.NATIVE_PROMPT_COLOR.get(
+        ReflectionHelper.getName(type(thing)),
+        c.DARK_BLUE
+    )
 
 def newLine(strReturn, charactere, prettyFunction, withColors):
-    if charactere == strReturn[-len(charactere):] :
-        return f'{c.NEW_LINE}'
+    if charactere == strReturn[-1][-len(charactere):] :
+        return [c.NEW_LINE]
     else :
-        return f'{getItAsColoredString(c.COMA, prettyFunction, withColors, color=c.COMA_PROMPT_COLOR)}{c.NEW_LINE}'
+        return [*getItAsColoredString(c.COMA, prettyFunction, withColors, color=c.COMA_PROMPT_COLOR), *c.NEW_LINE]
 
 def getValueCollection(outterValue) :
     return outterValue if not isinstance(outterValue, set) else ObjectHelper.getSortedCollection(outterValue)
 
 def getItAsColoredString(thing, prettyFunction, withColors, replaceBy=None, color=None) :
     thingValue = str(thing) if ObjectHelper.isNone(replaceBy) else str(replaceBy)
-    return thingValue if not withColors else f'{getColorValue(thing, color)}{thingValue}{c.RESET_COLOR}'
+    return [thingValue] if not withColors else [getColorValue(thing, color), thingValue, c.RESET_COLOR]
 
 def getFilteredAndColoredQuote(keyOrValue, string, prettyFunction, withColors, color) :
     if ObjectHelper.isNativeClassIsntance(keyOrValue) and not isinstance(keyOrValue, str) :
-        return c.NOTHING if StringHelper.prettyPython == prettyFunction else getItAsColoredString(string, prettyFunction, withColors, color=color)
+        return [c.NOTHING] if StringHelper.prettyPython == prettyFunction else getItAsColoredString(string, prettyFunction, withColors, color=color)
     return getItAsColoredString(string, prettyFunction, withColors, color=color)
 
 def getStrReturn(
@@ -35,13 +38,22 @@ def getStrReturn(
         falseValue,
         withColors
     ) :
-    valueValue = prettyFunction(value, quote=quote, tabCount=tabCount, nullValue=nullValue, trueValue=trueValue, falseValue=falseValue, withColors=withColors)
+    valueValue = prettyFunction(
+        value,
+        quote = quote,
+        tabCount = tabCount,
+        nullValue = nullValue,
+        trueValue = trueValue,
+        falseValue = falseValue,
+        withColors = withColors,
+        joinAtReturn = False
+    )
     if c.TYPE_DICT == collectionType :
         filteredAndColoredQuote = getFilteredAndColoredQuote(key, quote, prettyFunction, withColors, c.QUOTE_PROMPT_COLOR)
         filteredAndColoredColonSpace = getItAsColoredString(c.COLON_SPACE, prettyFunction, withColors, color=c.COLON_PROMPT_COLOR)
-        return f'{tabCount * c.TAB}{filteredAndColoredQuote}{getItAsColoredString(key if StringHelper.prettyPython==prettyFunction else StringHelper.filterString(prettyFunction(key, quote=quote, tabCount=tabCount, nullValue=nullValue, trueValue=trueValue, falseValue=falseValue)), prettyFunction, withColors)}{filteredAndColoredQuote}{filteredAndColoredColonSpace}{valueValue}'
+        return [tabCount * c.TAB, *filteredAndColoredQuote, *getItAsColoredString(key if StringHelper.prettyPython==prettyFunction else StringHelper.filterString(prettyFunction(key, quote=quote, tabCount=tabCount, nullValue=nullValue, trueValue=trueValue, falseValue=falseValue)), prettyFunction, withColors), *filteredAndColoredQuote, *filteredAndColoredColonSpace, *valueValue]
     else :
-        return f'{tabCount * c.TAB}{valueValue}'
+        return [tabCount * c.TAB, *valueValue]
 
 def prettyInstance(
         outterValue,
@@ -51,10 +63,10 @@ def prettyInstance(
         nullValue,
         trueValue,
         falseValue,
-        withColors=False
+        withColors=False,
+        joinAtReturn=False
     ) :
-    strReturn = c.NOTHING
-    filteredAndColoredQuote = getFilteredAndColoredQuote(outterValue, quote, prettyFunction, withColors, c.QUOTE_PROMPT_COLOR)
+    strReturn = []
     if (isinstance(outterValue, int) or isinstance(outterValue, float)) and not isinstance(outterValue, bool) :
         strReturn += getItAsColoredString(outterValue, prettyFunction, withColors)
     elif isinstance(outterValue, bool) :
@@ -65,8 +77,21 @@ def prettyInstance(
     elif ObjectHelper.isNone(outterValue) :
         strReturn += getItAsColoredString(outterValue, prettyFunction, withColors, replaceBy=nullValue, color=c.NONE_PROMP_COLOR)
     else :
-        strReturn += f'{filteredAndColoredQuote}{getItAsColoredString(outterValue, prettyFunction, withColors)}{filteredAndColoredQuote}'
-    return strReturn
+        filteredAndColoredQuote = getFilteredAndColoredQuote(outterValue, quote, prettyFunction, withColors, c.QUOTE_PROMPT_COLOR)
+        strReturn += [*filteredAndColoredQuote, *getItAsColoredString(outterValue, prettyFunction, withColors), *filteredAndColoredQuote]
+    return returnStr(strReturn, joinAtReturn)
+
+def getCollectionCharacter(collectionType, openOrClose, withColors) :
+    return c.COLLECTION_TYPE.get(
+        collectionType,
+        c.COLLECTION_TYPE.get(c.TYPE_LIST)
+    ).get(openOrClose).get(
+        withColors,
+        c.COLLECTION_TYPE.get(
+            collectionType,
+            c.COLLECTION_TYPE.get(c.TYPE_LIST)
+        ).get(openOrClose).get(c.WITHOUT_COLOR)
+    )
 
 def prettyCollection(
         outterValue,
@@ -77,15 +102,16 @@ def prettyCollection(
         nullValue,
         trueValue,
         falseValue,
-        withColors=False
+        withColors=False,
+        joinAtReturn=False
     ) :
-    openCollection = c.COLLECTION_TYPE.get(collectionType, c.COLLECTION_TYPE.get(c.TYPE_LIST)).get(c.OPEN_COLLECTION).get(withColors, c.COLLECTION_TYPE.get(collectionType, c.COLLECTION_TYPE.get(c.TYPE_LIST)).get(c.OPEN_COLLECTION).get(c.WITHOUT_COLOR))
-    closeCollection = c.COLLECTION_TYPE.get(collectionType, c.COLLECTION_TYPE.get(c.TYPE_LIST)).get(c.CLOSE_COLLECTION).get(withColors, c.COLLECTION_TYPE.get(collectionType, c.COLLECTION_TYPE.get(c.TYPE_LIST)).get(c.CLOSE_COLLECTION).get(c.WITHOUT_COLOR))
-    strReturn = c.NOTHING
+    openCollection = getCollectionCharacter(collectionType, c.OPEN_COLLECTION, withColors)
+    closeCollection = getCollectionCharacter(collectionType, c.CLOSE_COLLECTION, withColors)
+    strReturn = []
     if len(outterValue) == 0 :
-        strReturn += f'{openCollection}{closeCollection}'
+        strReturn += [openCollection, closeCollection]
     else :
-        strReturn += openCollection
+        strReturn += [openCollection]
         tabCount += 1
         if ObjectHelper.isDictionary(outterValue) :
             for key,value in outterValue.items() :
@@ -95,10 +121,13 @@ def prettyCollection(
             for value in outterValue :
                 strReturn += newLine(strReturn, openCollection, prettyFunction, withColors)
                 strReturn += getStrReturn(None, value, collectionType, quote, prettyFunction, tabCount, nullValue, trueValue, falseValue, withColors)
-        strReturn += c.NEW_LINE
+        strReturn += [c.NEW_LINE]
         tabCount -= 1
-        strReturn += f'{tabCount * c.TAB}{closeCollection}'
-    return strReturn
+        strReturn += [tabCount * c.TAB, closeCollection]
+    return returnStr(strReturn, joinAtReturn)
+
+def returnStr(strReturn, joinAtReturn) :
+    return strReturn if not joinAtReturn else StringHelper.join(strReturn)
 
 def isNotOneLineLongString(quoteType, thing) :
     if isinstance(thing, str) and isinstance(quoteType, str) and quoteType in [c.TRIPLE_SINGLE_QUOTE, c.TRIPLE_DOUBLE_QUOTE] :
